import os
from prompt_builder import _PromptBuilder
from job_manager import _JobManager
from constants import ANSWER, CONTEXT


def assess_groundedness_template(
    *,
    annotation_template,
    target_df,
    max_inputs,
    max_prompt_tokens,
    num_samples,
    total_samples,
    request_args,
    endpoint_args,
    output_fp,
    min_score,
    max_score,
    seed
):
    """Assess groundedness."""
    for col_name in [ANSWER, CONTEXT]:
        if col_name not in target_df.columns:
            raise ValueError(f"target_dataset must have column: {col_name}")

    # Sampling
    target_df = target_df.sample(replace=False, n=total_samples, random_state=seed)

    prompt_builder = _PromptBuilder(
        labeling_guidelines=annotation_template,
        model_name=endpoint_args["model"],
        max_tokens=max_prompt_tokens,
        max_shots=0,
        min_input_examples=1,
    )

    # _JobManager handles batching and retry logic
    job_manager = _JobManager(
        output_fp=output_fp,
        prompt_builder=prompt_builder
    )

    annotations_df = job_manager.submit_inputs(
                input_data_df=target_df,
                request_args=request_args,
                max_inputs=max_inputs,
                num_samples=num_samples,
                min_score=min_score,
                max_score=max_score,
                **endpoint_args,
    )

    return annotations_df


def test_benchmark(output_dir, sample_size, model, annotation_template, min_score, max_score, benchmark_df, eval_func, n_prompts_per_call, seed): # prompt_generate_func takes in min score and max score to generate a template
    output_fp = f"{output_dir}/result.csv"
    confusion_matrix_fp = f"{output_dir}/confusion.csv"
    try:
        os.remove(output_fp)
        os.remove(confusion_matrix_fp)
    except:
        pass

    request_args = {
            "model": model,
            "temperature": 0,
            "top_p": 1,
            "num_samples": 1,
            "max_tokens": 1000,
            "frequency_penalty": 0,
            "presence_penalty": 0
    }

    endpoint_args = {"model": model,
                     "token": "x"}

    annotated = assess_groundedness_template(
        annotation_template=annotation_template,
        target_df=benchmark_df,
        max_inputs=n_prompts_per_call,
        max_prompt_tokens=4000,
        num_samples=1,
        total_samples=sample_size,
        request_args=request_args,
        endpoint_args=endpoint_args,
        output_fp=output_fp,
        min_score=min_score,
        max_score=max_score,
        seed=seed
    )

    acc = eval_func(annotated, confusion_matrix_fp)
    return acc