from sklearn.metrics import accuracy_score, confusion_matrix
import pandas as pd
from assessment_flow import test_benchmark

def eval_binary(df, save_fp):
    if df.shape[0] == 0:
        return 0
    df["rating"]=df["rating"].astype(int)
    accuracy = accuracy_score(df['label_true'], df['rating'])
    confusion = confusion_matrix(df['label_true'], df['rating'])
    confusion_matrix_df = pd.DataFrame(confusion, columns=["predicted-0", "predicted-1"], index=["actual-0", "actual-1"])
    print(confusion_matrix_df)
    confusion_matrix_df.to_csv(save_fp)
    return accuracy

def eval_7class(df, save_fp):
    if df.shape[0] == 0:
        return 0
    df["rating"]=df["rating"].astype(int)
    accuracy = accuracy_score(df['label_true'], df['rating'])
    confusion = confusion_matrix(df['label_true'], df['rating'],labels=[1,2,3,4,5,6,7])
    confusion_matrix_df = pd.DataFrame(confusion, columns=["predicted-1", "predicted-2", "predicted-3", "predicted-4", "predicted-5", "predicted-6", "predicted-7"],
                                       index=["actual-1", "actual-2", "actual-3", "actual-4", "actual-5", "actual-6", "actual-7"])
    print(confusion_matrix_df)
    confusion_matrix_df.to_csv(save_fp)
    return accuracy

def repeat_sample_test_benchmark(n_repeat, output_dir, sample_size, model, prompt_generate_func, min_score, max_score, prep_data_func, eval_func, n_prompts_per_call, n_repeat_startidx=0):
    res = []
    for i in range(n_repeat):
        if i < n_repeat_startidx:
            continue
        print(f"---------------benchmark test # {i}------------------")
        # run with seed=i
        cur_acc = test_benchmark(f"{output_dir}/run{i}", sample_size, model, prompt_generate_func, min_score, max_score, prep_data_func, eval_func, n_prompts_per_call, i)
        print(f"cur run accuracy: {cur_acc}")
        res.append(cur_acc)
    return res

