from requests.adapters import HTTPAdapter
from requests.packages.urllib3.util.retry import Retry
import requests
from prompt_data import _PromptData

class _HTTPClientWithRetry:
    def __init__(self, n_retry, backoff_factor):
        self.attempts = n_retry

        retry_strategy = Retry(
            total=n_retry,
            status_forcelist=[104, 408, 409, 424, 429, 500, 502, 503, 504],
            backoff_factor=backoff_factor,
            respect_retry_after_header=True,
        )
        adapter = HTTPAdapter(max_retries=retry_strategy)
        self.client = requests.Session()
        self.client.mount("https://", adapter)

class _Job:
    """Job state for prompts submitted to model engines."""

    def __init__(
        self,
        job_idx: int,
        prompt_data: _PromptData,
        request_params: dict,
        retries_attempted: int = 0,
        response_data: dict = None,
        status: str = None,
    ):
        self.job_idx = job_idx
        self.prompt_data = prompt_data
        self.request_params = request_params
        self.retries_attempted = retries_attempted
        self.response_data = response_data or {}
        self.status = status

    def get_output_data(self) -> dict:
        """Return the data which gets written to output."""
        return {
            **(self.prompt_data.__dict__),
            **self.response_data,
            "retries": self.retries_attempted,
            "status": self.status,
        }