import sys
from azureml.core import ScriptRunConfig
from azureml.core import Experiment
from azureml.core import Environment
import click
from aml_auth import get_aml_workspace


@click.command()
@click.option('--area', type=str, help='groundedness/contentharm/...')
@click.option('--samples_per_benchmark', type=str, help='number of samples per benchmark')
@click.option('--experiment_name', type=str, help='name of experiment')
@click.option('--prompt_file', type=str, help='file path of prompt')
@click.option('--model_name', type=str, help='name of model, gpt-35-turbo for example')
def main():

    myenv = Environment("user-managed-env")
    myenv.python.user_managed_dependencies = True

    script_params = [
      "--area",
      area,
      "--samples_per_benchmark",
      samples_per_benchmark,
      "--experiment_name",
      experiment_name,
      "--prompt_file",
      prompt_file,
      "--model_name",
      model_name
    ]
    src = ScriptRunConfig(source_directory="./",
                        script='e2e_exp.py',
                        compute_target='local',
                        environment=myenv,
                        arguments=script_params
                        )

    ws = get_aml_workspace()
    experiment = Experiment(workspace=ws, name=experiment_name)
    run = experiment.submit(config=src)


if __name__ == '__main__':
    main()